data-md.core


default-optionsclj/s

Default options used by all public data-md functions.

Default options used by all public data-md functions.
sourceraw docstring

read-edn-formsclj/s≠

clj
(read-edn-forms source)
(read-edn-forms source opts)

Read all EDN values from a java.io.Reader or file path.

Read all EDN values from a java.io.Reader or file path.
cljs
(read-edn-forms & _)

File I/O is available on the JVM and Babashka only.

File I/O is available on the JVM and Babashka only.
source (clj)source (cljs)raw docstring

renderclj/s

(render data)
(render data opts)

Render a Clojure/EDN value as GitHub-Flavored Markdown.

Returns a Markdown string.

Render a Clojure/EDN value as GitHub-Flavored Markdown.

Returns a Markdown string.
sourceraw docstring

render-fileclj/s≠

clj
(render-file path)
(render-file path opts)

Read EDN values from path and render them as Markdown.

Read EDN values from path and render them as Markdown.
cljs
(render-file & _)

File I/O is available on the JVM and Babashka only.

File I/O is available on the JVM and Babashka only.
source (clj)source (cljs)raw docstring

render-formsclj/s

(render-forms forms)
(render-forms forms opts)

Render one or more top-level Clojure/EDN values as one Markdown document.

A single value renders exactly like render. Multiple values are grouped under numbered form sections.

Render one or more top-level Clojure/EDN values as one Markdown document.

A single value renders exactly like render. Multiple values are grouped under
numbered form sections.
sourceraw docstring

render-tableclj/s

(render-table rows)
(render-table rows opts)

Render row data as a GitHub-Flavored Markdown pipe table.

Rows may be a sequence of maps. A sequence of vectors is supported when :columns is supplied.

Render row data as a GitHub-Flavored Markdown pipe table.

Rows may be a sequence of maps. A sequence of vectors is supported when
:columns is supplied.
sourceraw docstring

write-file!clj/s≠

clj
(write-file! edn-path md-path)
(write-file! edn-path md-path opts)

Read EDN from edn-path, render Markdown, write md-path, and return md-path.

Read EDN from edn-path, render Markdown, write md-path, and return md-path.
cljs
(write-file! & _)

File I/O is available on the JVM and Babashka only.

File I/O is available on the JVM and Babashka only.
source (clj)source (cljs)raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries