data-md.escape


code-spanclj/s

(code-span s)

Render s as an inline Markdown code span, handling embedded backticks.

Render s as an inline Markdown code span, handling embedded backticks.
sourceraw docstring

escape-headingclj/s

(escape-heading s)

Escape a single-line Markdown heading label.

Escape a single-line Markdown heading label.
sourceraw docstring

escape-table-cellclj/s

(escape-table-cell s)
(escape-table-cell s opts)

Escape inline Markdown for use inside a GFM table cell.

Escape inline Markdown for use inside a GFM table cell.
sourceraw docstring

escape-textclj/s

(escape-text s)

Escape prose text for GitHub-Flavored Markdown.

Escape prose text for GitHub-Flavored Markdown.
sourceraw docstring

fenced-codeclj/s

(fenced-code s)
(fenced-code s opts)

Render s as a fenced code block.

Render s as a fenced code block.
sourceraw docstring

normalize-newlinesclj/s

(normalize-newlines s)

Normalize CRLF and CR line endings to LF.

Normalize CRLF and CR line endings to LF.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries