data-md.io


edn-read-optionsclj

(edn-read-options opts)
source

read-edn-fileclj

(read-edn-file path opts)

Read exactly one EDN value from path.

Read exactly one EDN value from path.
sourceraw docstring

read-edn-forms-fileclj

(read-edn-forms-file path opts)

Read all EDN values from path.

Read all EDN values from path.
sourceraw docstring

read-edn-forms-readerclj

(read-edn-forms-reader reader opts)

Read all EDN values from reader.

Read all EDN values from reader.
sourceraw docstring

read-edn-readerclj

(read-edn-reader reader opts)

Read exactly one EDN value from reader.

Read exactly one EDN value from reader.
sourceraw docstring

write-markdown-file!clj

(write-markdown-file! path markdown)

Write markdown to path, creating parent directories as needed.

Write markdown to path, creating parent directories as needed.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries