(compact-pr-str value)Return a single-line printable representation for value.
Return a single-line printable representation for value.
(pretty-str value)Return clojure.pprint output for value, falling back to safe-pr-str.
Return clojure.pprint output for value, falling back to safe-pr-str.
(safe-pr-str value)Return pr-str for value, falling back to str if printing fails.
Return pr-str for value, falling back to str if printing fails.
(short-inline? s)(short-inline? s max-length)True when s is short enough for an inline code span.
True when s is short enough for an inline code span.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |