Default options used by all public data-md functions.
Default options used by all public data-md functions.
(render data)(render data opts)Render a Clojure/EDN value as GitHub-Flavored Markdown.
Returns a Markdown string.
Render a Clojure/EDN value as GitHub-Flavored Markdown. Returns a Markdown string.
(render-file path)(render-file path opts)Read one EDN value from path and render it as Markdown.
Read one EDN value from path and render it as Markdown.
(render-file & _)File I/O is available on the JVM and Babashka only.
File I/O is available on the JVM and Babashka only.
(render-table rows)(render-table rows opts)Render row data as a GitHub-Flavored Markdown pipe table.
Rows may be a sequence of maps. A sequence of vectors is supported when :columns is supplied.
Render row data as a GitHub-Flavored Markdown pipe table. Rows may be a sequence of maps. A sequence of vectors is supported when :columns is supplied.
(write-file! edn-path md-path)(write-file! edn-path md-path opts)Read EDN from edn-path, render Markdown, write md-path, and return md-path.
Read EDN from edn-path, render Markdown, write md-path, and return md-path.
(write-file! & _)File I/O is available on the JVM and Babashka only.
File I/O is available on the JVM and Babashka only.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |