data-md.pprint


compact-pr-strclj/s

(compact-pr-str value)

Return a single-line printable representation for value.

Return a single-line printable representation for value.
sourceraw docstring

pretty-strclj/s

(pretty-str value)

Return clojure.pprint output for value, falling back to safe-pr-str.

Return clojure.pprint output for value, falling back to safe-pr-str.
sourceraw docstring

safe-pr-strclj/s

(safe-pr-str value)

Return pr-str for value, falling back to str if printing fails.

Return pr-str for value, falling back to str if printing fails.
sourceraw docstring

short-inline?clj/s

(short-inline? s)
(short-inline? s max-length)

True when s is short enough for an inline code span.

True when s is short enough for an inline code span.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries